﻿class SinWave {
	
	private var target_mc:MovieClip;
	private var steps:Number;
	private var sin_width:Number;
	private var sin_height:Number;
	private var phase:Number;
	private var inc:Number;
	private var stroke_weight:Number;
	private var stroke_color:Number;
	private var draw_fill:Boolean = false;
	private var fill_color:Number = 0xFF0000;
	private var fill_height:Number;
	private var fill_alpha:Number;
	private var step_x:Number;
	
	public function SinWave( _mc:MovieClip, // Movie clip the sin wave will be attached to
							s:Number, 		// The number of points usedto draw the wave
							w:Number, 		// Width of the wave
							h:Number, 		// Height of wave
							p:Number, 		// Phase of wave
							n:Number, 		// Number of cycles
							sw:Number, 		// Stroke width
							sc:Number ) {	// Stroke color
		
		var depth 	= _mc.getNextHighestDepth();
		target_mc 	= _mc.createEmptyMovieClip( "sin_" + depth, depth );
		steps		= s;
		sin_width	= w;
		sin_height	= h;
		phase		= p;
		inc			= n * Math.PI * 2 / steps;
		step_x 		= sin_width / steps;
		if ( sw != undefined ) {
			stroke_weight = sw;
		} else {
			stroke_weight = 1;
		}
		
		if ( sc != undefined ) {
			stroke_color  = sc;
		} else {
			stroke_color = 0x000000;
		}
		
		draw_sin();
	}
	
	private function draw_sin() {
		target_mc.clear();
		if ( stroke_weight > 0 ) {
			target_mc.lineStyle( stroke_weight, stroke_color );
		}
		if ( draw_fill ) {
			target_mc.beginFill( fill_color, fill_alpha );
		}
		
		var start_height = Math.sin( phase ) * sin_height
		target_mc.moveTo( 0, start_height );
		
		for ( var i = 1; i < steps + 1; i ++ ) {
			target_mc.lineTo( step_x * i, ( Math.sin( phase + ( inc * i ) ) * sin_height )  );
		}
		
		if ( draw_fill ) {
			target_mc.lineTo( sin_width, fill_height );
			target_mc.lineTo( 0, fill_height );
			target_mc.lineTo( 0, start_height );
			target_mc.endFill();
		}
	}
	
	public function inc_phase( n:Number ) {
		phase += n;
		draw_sin();
	}
	
	public function set_height( n:Number ) {
		sin_height = n;
		draw_sin();
	}
	
	public function set_fill( onOff:Boolean, c:Number, h:Number, a:Number ):Void {
		draw_fill = onOff;
		fill_color = c;
		fill_height = h;
		fill_alpha = a;
		draw_sin();
	}
	
}


